@@ -1,9 +1,15 @@
+from typing import Any
+from typing import Optional
+from typing import Tuple
+
 from torch import Tensor
 from torch.nn import Module
 
 
-def save_prev_output(module: Module, input: Tensor, output: Tensor) -> None:
-    """A hook to save previous output as a buffer named `prev_output`.
+def save_prev_output(
+    module: Module, input: Tuple[Any, ...], output: Optional[Tensor]
+) -> None:
+    """A hook to save previous output as a buffer named ``prev_output``.
 
     Examples:
 
@@ -13,8 +19,8 @@ def save_prev_output(module: Module, input: Tensor, output: Tensor) -> None:
         >>> hook = m.register_forward_hook(save_prev_output)
         >>> input = torch.randn(1, 3)
         >>> m(input)
-        tensor([[-1.1647,  0.0244]], grad_fn=<AddmmBackward>)
+        tensor([[-1.1647,  0.0244]], ...)
         >>> m.prev_output
-        tensor([[-1.1647,  0.0244]], grad_fn=<AddmmBackward>)
+        tensor([[-1.1647,  0.0244]], ...)
     """
     module.register_buffer("prev_output", output, persistent=False)
