@@ -1,4 +1,3 @@
-import torch
 from torch import Tensor
 from torch.nn import Module
 
@@ -18,7 +17,7 @@ class Naked(Module):
           :math:`H_{\\text{out}}` is the number of output features.
 
     Examples:
-
+        >>> import torch
         >>> from pfhedge.nn import Naked
         >>>
         >>> m = Naked()
