@@ -1,21 +1,22 @@
-from typing import Any
 from typing import Callable
 from typing import Optional
 from typing import Tuple
 from typing import Union
-from typing import cast
 
 import torch
 from torch import Tensor
 
 from pfhedge._utils.typing import TensorOrScalar
 
+from ._utils import cast_state
+
 
 def generate_brownian(
     n_paths: int,
     n_steps: int,
     init_state: Union[Tuple[TensorOrScalar, ...], TensorOrScalar] = (0.0,),
     sigma: float = 0.2,
+    mu: float = 0.0,
     dt: float = 1 / 250,
     dtype: Optional[torch.dtype] = None,
     device: Optional[torch.device] = None,
@@ -26,7 +27,7 @@ def generate_brownian(
     The time evolution of the process is given by:
 
     .. math::
-        dS(t) = \sigma dW(t) \,.
+        dS(t) = \mu dt + \sigma dW(t) \,.
 
     Args:
         n_paths (int): The number of simulated paths.
@@ -37,6 +38,8 @@ def generate_brownian(
             It also accepts a :class:`torch.Tensor` or a :class:`float`.
         sigma (float, default=0.2): The parameter :math:`\sigma`,
             which stands for the volatility of the time series.
+        mu (float, default=0.0): The parameter :math:`\mu`,
+            which stands for the drift of the time series.
         dt (float, default=1/250): The intervals of the time steps.
         dtype (torch.dtype, optional): The desired data type of returned tensor.
             Default: If ``None``, uses a global default
@@ -68,20 +71,15 @@ def generate_brownian(
         tensor([[ 0.0000,  0.0016,  0.0046,  0.0075, -0.0067],
                 [ 0.0000,  0.0279,  0.0199,  0.0257,  0.0291]])
     """
-    # Accept Union[float, Tensor] as well because making a tuple with a single element
-    # is troublesome
-    if isinstance(init_state, (float, Tensor)):
-        init_state = (init_state,)
-
-    # Cast to init_state: Tuple[Tensor, ...] with desired dtype and device
-    init_state = cast(Tuple[Tensor, ...], tuple(map(torch.as_tensor, init_state)))
-    init_state = tuple(map(lambda t: t.to(dtype=dtype, device=device), init_state))
+    init_state = cast_state(init_state, dtype=dtype, device=device)
 
     init_value = init_state[0]
     # randn = torch.randn((n_paths, n_steps), dtype=dtype, device=device)
-    randn = engine((n_paths, n_steps), dtype=dtype, device=device)
+    randn = engine(*(n_paths, n_steps), dtype=dtype, device=device)
     randn[:, 0] = 0.0
-    return sigma * randn.new_tensor(dt).sqrt() * randn.cumsum(1) + init_value
+    drift = mu * dt * torch.arange(n_steps).to(randn)
+    brown = randn.new_tensor(dt).sqrt() * randn.cumsum(1)
+    return drift + sigma * brown + init_value
 
 
 def generate_geometric_brownian(
@@ -89,6 +87,7 @@ def generate_geometric_brownian(
     n_steps: int,
     init_state: Union[Tuple[TensorOrScalar, ...], TensorOrScalar] = (1.0,),
     sigma: float = 0.2,
+    mu: float = 0.0,
     dt: float = 1 / 250,
     dtype: Optional[torch.dtype] = None,
     device: Optional[torch.device] = None,
@@ -100,7 +99,7 @@ def generate_geometric_brownian(
 
     .. math::
 
-        dS(t) = \sigma S(t) dW(t) \,.
+        dS(t) = \mu S(t) dt + \sigma S(t) dW(t) \,.
 
     Args:
         n_paths (int): The number of simulated paths.
@@ -109,7 +108,9 @@ def generate_geometric_brownian(
             the time series.
             This is specified by a tuple :math:`(S(0),)`.
             It also accepts a :class:`torch.Tensor` or a :class:`float`.
-        sigma (float, default=0.2): The parameter :math:`sigma`,
+        sigma (float, default=0.2): The parameter :math:`\sigma`,
+            which stands for the volatility of the time series.
+        mu (float, default=0.2): The parameter :math:`\mu`,
             which stands for the volatility of the time series.
         dt (float, default=1/250): The intervals of the time steps.
         dtype (torch.dtype, optional): The desired data type of returned tensor.
@@ -142,24 +143,18 @@ def generate_geometric_brownian(
         tensor([[1.0000, 1.0016, 1.0044, 1.0073, 0.9930],
                 [1.0000, 1.0282, 1.0199, 1.0258, 1.0292]])
     """
-    # Accept Union[float, Tensor] as well because making a tuple with a single element
-    # is troublesome
-    if isinstance(init_state, (float, Tensor)):
-        init_state = (init_state,)
-
-    # Cast to init_state: Tuple[Tensor, ...] with desired dtype and device
-    init_state = cast(Tuple[Tensor, ...], tuple(map(torch.as_tensor, init_state)))
-    init_state = tuple(map(lambda t: t.to(dtype=dtype, device=device), init_state))
+    init_state = cast_state(init_state, dtype=dtype, device=device)
 
     brownian = generate_brownian(
         n_paths=n_paths,
         n_steps=n_steps,
         init_state=(0.0,),
         sigma=sigma,
+        mu=mu,
         dt=dt,
         dtype=dtype,
         device=device,
         engine=engine,
     )
     t = dt * torch.arange(n_steps).to(brownian).unsqueeze(0)
-    return init_state[0] * (brownian - (sigma**2) * t / 2).exp()
+    return init_state[0] * (brownian - (sigma ** 2) * t / 2).exp()
